@@ -1,8 +1,8 @@
 devtools::use_package("devtools")
-library("devtools")
+# library("devtools")
 
-descrip            = readLines("DESCRIPTION")
-spectrolab_version = tolower(descrip[ grep("Version:", descrip) ])
+descrip             = readLines("DESCRIPTION")
+spectrolab_version  = tolower(descrip[ grep("Version:", descrip) ])
 spectrolab_citation = format(citation("spectrolab"), style = "text")
 spectrolab_citation = gsub("_", "", spectrolab_citation)
 
